.. _objects:

*******
Objects
*******

Objects Base
============
.. automodule:: designate.objects.base
    :members:
    :undoc-members:
    :show-inheritance:


Objects Backlist
================
.. automodule:: designate.objects.blacklist
    :members:
    :undoc-members:
    :show-inheritance:


Objects Zone
============
.. automodule:: designate.objects.zone
    :members:
    :undoc-members:
    :show-inheritance:


Objects Pool
============
.. automodule:: designate.objects.pool
    :members:
    :undoc-members:
    :show-inheritance:


Objects Quota
=============
.. automodule:: designate.objects.quota
    :members:
    :undoc-members:
    :show-inheritance:


Objects Record
==============
.. automodule:: designate.objects.record
    :members:
    :undoc-members:
    :show-inheritance:


Objects Recordset
=================
.. automodule:: designate.objects.recordset
    :members:
    :undoc-members:
    :show-inheritance:


Objects Server
==============
.. automodule:: designate.objects.server
    :members:
    :undoc-members:
    :show-inheritance:


Objects Tenant
==============
.. automodule:: designate.objects.tenant
    :members:
    :undoc-members:
    :show-inheritance:


Objects TLD
===========
.. automodule:: designate.objects.tld
    :members:
    :undoc-members:
    :show-inheritance:


Objects TSigKey
===============
.. automodule:: designate.objects.tsigkey
    :members:
    :undoc-members:
    :show-inheritance:


Objects A Record
================
.. automodule:: designate.objects.rrdata_a
    :members:
    :undoc-members:
    :show-inheritance:


Objects AAAA Record
===================
.. automodule:: designate.objects.rrdata_aaaa
    :members:
    :undoc-members:
    :show-inheritance:


Objects CNAME Record
====================
.. automodule:: designate.objects.rrdata_cname
    :members:
    :undoc-members:
    :show-inheritance:


Objects MX Record
=================
.. automodule:: designate.objects.rrdata_mx
    :members:
    :undoc-members:
    :show-inheritance:


Objects NS Record
=================
.. automodule:: designate.objects.rrdata_ns
    :members:
    :undoc-members:
    :show-inheritance:


Objects PTR Record
==================
.. automodule:: designate.objects.rrdata_ptr
    :members:
    :undoc-members:
    :show-inheritance:


Objects SOA Record
==================
.. automodule:: designate.objects.rrdata_soa
    :members:
    :undoc-members:
    :show-inheritance:


Objects SPF Record
==================
.. automodule:: designate.objects.rrdata_spf
    :members:
    :undoc-members:
    :show-inheritance:


Objects SRV Record
==================
.. automodule:: designate.objects.rrdata_srv
    :members:
    :undoc-members:
    :show-inheritance:


Objects TXT Record
==================
.. automodule:: designate.objects.rrdata_txt
    :members:
    :undoc-members:
    :show-inheritance:


Objects SSHFP Record
====================
.. automodule:: designate.objects.rrdata_sshfp
    :members:
    :undoc-members:
    :show-inheritance:


Objects NAPTR Record
====================
.. automodule:: designate.objects.rrdata_naptr
    :members:
    :undoc-members:
    :show-inheritance:


Objects CAA Record
====================
.. automodule:: designate.objects.rrdata_caa

    :members:
    :undoc-members:
    :show-inheritance:
